@@ -6,7 +6,6 @@
 applications across platforms.
 
 """
-import mozinfo
 from optparse import OptionParser
 import os
 import shutil
@@ -16,6 +15,9 @@ import tarfile
 import time
 import zipfile
 
+import mozfile
+import mozinfo
+
 if mozinfo.isMac:
     from plistlib import readPlist
 
@@ -60,7 +62,8 @@ def get_binary(path, app_name):
     # On OS X we can get the real binary from the app bundle
     if mozinfo.isMac:
         plist = '%s/Contents/Info.plist' % path
-        assert os.path.isfile(plist), '"%s" has not been found.' % plist
+        if not os.path.isfile(plist):
+            raise InvalidBinary('%s/Contents/Info.plist not found' % path)
 
         binary = os.path.join(path, 'Contents/MacOS/',
                               readPlist(plist)['CFBundleExecutable'])
@@ -81,7 +84,7 @@ def get_binary(path, app_name):
     if not binary:
         # The expected binary has not been found. Make sure we clean the
         # install folder to remove any traces
-        shutil.rmtree(path)
+        mozfile.remove(path)
 
         raise InvalidBinary('"%s" does not contain a valid binary.' % path)
 
@@ -112,7 +115,7 @@ def install(src, dest):
     try:
         install_dir = None
         if zipfile.is_zipfile(src) or tarfile.is_tarfile(src):
-            install_dir = _extract(src, dest)[0]
+            install_dir = mozfile.extract(src, dest)[0]
         elif src.lower().endswith('.dmg'):
             install_dir = _install_dmg(src, dest)
         elif src.lower().endswith('.exe'):
@@ -144,7 +147,9 @@ def is_installer(src):
 
     """
     src = os.path.realpath(src)
-    assert os.path.isfile(src), 'Installer has to be a file'
+
+    if not os.path.isfile(src):
+        return False
 
     if mozinfo.isLinux:
         return tarfile.is_tarfile(src)
@@ -202,64 +207,7 @@ def uninstall(install_folder):
 
     # Ensure that we remove any trace of the installation. Even the uninstaller
     # on Windows leaves files behind we have to explicitely remove.
-    shutil.rmtree(install_folder)
-
-
-def _extract(src, dest):
-    """Extract a tar or zip file into the destination folder and return the
-    application folder.
-
-    Arguments:
-    src -- archive which has to be extracted
-    dest -- the path to extract to
-
-    """
-    if zipfile.is_zipfile(src):
-        bundle = zipfile.ZipFile(src)
-        namelist = bundle.namelist()
-
-        if hasattr(bundle, 'extractall'):
-            # zipfile.extractall doesn't exist in Python 2.5
-            bundle.extractall(path=dest)
-        else:
-            for name in namelist:
-                filename = os.path.realpath(os.path.join(dest, name))
-                if name.endswith('/'):
-                    os.makedirs(filename)
-                else:
-                    path = os.path.dirname(filename)
-                    if not os.path.isdir(path):
-                        os.makedirs(path)
-                    dest = open(filename, 'wb')
-                    dest.write(bundle.read(name))
-                    dest.close()
-
-    elif tarfile.is_tarfile(src):
-        bundle = tarfile.open(src)
-        namelist = bundle.getnames()
-
-        if hasattr(bundle, 'extractall'):
-            # tarfile.extractall doesn't exist in Python 2.4
-            bundle.extractall(path=dest)
-        else:
-            for name in namelist:
-                bundle.extract(name, path=dest)
-    else:
-        return
-
-    bundle.close()
-
-    # namelist returns paths with forward slashes even in windows
-    top_level_files = [os.path.join(dest, name) for name in namelist
-                             if len(name.rstrip('/').split('/')) == 1]
-
-    # namelist doesn't include folders, append these to the list
-    for name in namelist:
-        root = os.path.join(dest, name[:name.find('/')])
-        if root not in top_level_files:
-            top_level_files.append(root)
-
-    return top_level_files
+    mozfile.remove(install_folder)
 
 
 def _install_dmg(src, dest):
